if(ThingsToDo2 == nil) then
	ThingsToDo2 = {}
end
local ttd2 = ThingsToDo2

if(ttd2.lib == nil) then
	ttd2.lib = {}
end
local lib = ttd2.lib

if(ttd2.option == nil) then
	ttd2.option = {}
end
local option = ttd2.option

if(ttd2.mod == nil) then
	ttd2.mod = {}
end
local mod = ttd2.mod

--this module
ttd2.ArgusEgg = {}
local this = ttd2.ArgusEgg
this.Name = "[Argus] Egg"

--[[
The purpose of this module is to check if you own the various collectibles from the egg-item looted on argus and
check available WQ-Sources for them if you don't have them.

NOTE: This module will only print "todo" status if the WQ is up. If the source is not looted but the WQ is not up
"done2" will be used instead.
]]

this.private = { set = false }
function this.private.Validate()
	if(this.private.set == false) then
		this.private.Init()
		this.private.set = true
	end
	
	return
end

function this.private.Init()
	if(this.private.set == true) then
		return
	end
	
	this.private.Egg =
	{
		Item = { NormalID = 153190, CrackedID = 153191 },
		Content = 
		{
			Mounts =
			{
				{ ItemID = 152840, JournalID = 976 },
				{ ItemID = 152841, JournalID = 975 },
				{ ItemID = 152842, JournalID = 974 },
				{ ItemID = 152843, JournalID = 906 }
			},
			Pets =
			{
				{ ItemID = 153054, SpeciesID = 2118 },
				{ ItemID = 153055, SpeciesID = 2119 }
			}
		},
		SRC =
		{
			{ MapID = 830, PosX = 0.705, PosY = 0.337, FlagQuest = 48667, WQuest = 48502, Name = "Naroua" },	--Naroua
			{ MapID = 882, PosX = 0.442, PosY = 0.498, FlagQuest = 48712, WQuest = 48732, Name = "Sabuul" },	--Sabuul
			{ MapID = 885, PosX = 0.643, PosY = 0.482, FlagQuest = 48812, WQuest = 48827, Name = "Varga" }		--Varga
		}
	}
	
	lib.item.AddByID(this.private.Egg.Item.NormalID)
	lib.item.AddByID(this.private.Egg.Item.CrackedID)
	
	for _, Mount in pairs(this.private.Egg.Content.Mounts) do
		lib.item.AddByID(Mount.ItemID)
		lib.journal.mount.AddByID(Mount.JournalID)
	end
	
	for _, Pet in pairs(this.private.Egg.Content.Pets) do
		lib.item.AddByID(Pet.ItemID)
		lib.journal.pet.AddByID(Pet.SpeciesID)
	end
	
	for _, SRC in pairs(this.private.Egg.SRC) do
		lib.quest.AddByID(SRC.FlagQuest)
	end
	
	return
end

function this.private.Update()
	this.private.Validate()
	
	local SomethingMissing	= false
	local SourcesAvailable	= false
	local WQsAvailable		= false
	
	lib.item.UpdateByID(this.private.Egg.Item.NormalID)
	lib.item.UpdateByID(this.private.Egg.Item.CrackedID)
	
	for _, Mount in pairs(this.private.Egg.Content.Mounts) do
		lib.item.UpdateByID(Mount.ItemID)
		lib.journal.mount.UpdateByID(Mount.JournalID)
		if(lib.journal.mount.GetByID(Mount.JournalID).IsCollected ~= true) then
			SomethingMissing = true
		end
	end
	
	for _, Pet in pairs(this.private.Egg.Content.Pets) do
		lib.item.UpdateByID(Pet.ItemID)
		lib.journal.pet.UpdateByID(Pet.SpeciesID)
		if(lib.journal.pet.GetByID(Pet.SpeciesID).IsCollected ~= true) then
			SomethingMissing = true
		end
	end
	
	for _, SRC in pairs(this.private.Egg.SRC) do
		lib.quest.UpdateByID(SRC.FlagQuest)
		if(lib.quest.GetByID(SRC.FlagQuest).IsCompleted ~= true) then
			SourcesAvailable = true
			if(lib.worldquest.IsActive(SRC.WQuest) == true) then
				WQsAvailable = true
			end
		end
		SRC.Name = lib.worldquest.GetNameByID(SRC.WQuest)
	end
	
	local out = lib.chat.output
	out.ClearBuffer()
	
	local OutputFunction = nil
	if(WQsAvailable == true) then
		OutputFunction = out.StoreTodo		--there is a source available
	elseif(SourcesAvailable == true) then
		OutputFunction = out.StoreRare		--there may be a source available
	else
		OutputFunction = out.StoreDone		--there is no source available
	end
	
	local EggLink = lib.item.GetByID(this.private.Egg.Item.NormalID).Link.." >> "..lib.item.GetByID(this.private.Egg.Item.CrackedID).Link
	if(SomethingMissing == false) then
		out.StoreCompleted(EggLink)
	else
		OutputFunction(EggLink)
	end
	
	for _, Mount in pairs(this.private.Egg.Content.Mounts) do
		local msg = lib.item.GetByID(Mount.ItemID).Link
		if(lib.journal.mount.GetByID(Mount.JournalID).IsCollected == true) then
			out.StoreCompleted(msg)
		else
			OutputFunction(msg)
		end
	end

	for _, Pet in pairs(this.private.Egg.Content.Pets) do
		local msg = lib.item.GetByID(Pet.ItemID).Link
		if(lib.journal.pet.GetByID(Pet.SpeciesID).IsCollected == true) then
			out.StoreCompleted(msg)
		else
			OutputFunction(msg)
		end
	end
	
	--now list sources; as these effect pets, done takes priority again
	for _, SRC in pairs(this.private.Egg.SRC) do
		if(lib.quest.GetByID(SRC.FlagQuest).IsCompleted == true) then
			--this source is looted, there is nothing more to do
			out.StoreDone(SRC.Name)
		elseif(SomethingMissing == true) then
			if(lib.worldquest.IsActive(SRC.WQuest) == true) then
				--this source is definetly there
				out.StoreTodo(lib.chat.complex.GetWQStatusString(SRC.WQuest))
			else
				--the source may be there
				local TomTom = lib.tomtom.createLink(SRC.MapID,SRC.PosX,SRC.PosY,SRC.Name)
				out.StoreRare(TomTom)
			end
		end
	end
	
	return
end

function this.CheckStatus()
	this.private.Validate()
	
	this.private.Update()
	if(lib.chat.output.GetNumLines() == 0) then
		return false
	end
	
	return true
end

function this.Script()
	this.private.Validate()
	
	this.private.Update()
	lib.chat.output.PrintModule(this.Name)
	
	return
end

mod[#mod+1] =
{
	CheckStatus	= this.CheckStatus,
	Text		= this.Name,
	Script		= this.Script
}
