if(ThingsToDo2 == nil) then
	ThingsToDo2 = {}
end
local ttd2 = ThingsToDo2

if(ttd2.mod == nil) then
	ttd2.mod = {}
end
local mod = ttd2.mod

local lib = ttd2.lib

--this module
ttd2.BFAMissableQuests = {}
local this = ttd2.BFAMissableQuests
this.Name = "[BFA] Missable Quests"

this.private = { set = false }
function this.private.Validate()
	if(this.private.set == false) then
		this.private.Init()
		this.private.set = true
	end
	return
end

function this.private.Init()
	if(this.private.set == true) then
		return
	end
	
	this.private.quests = nil
	
	local MyFaction = lib.unit.GetPlayerFaction()
	if(MyFaction == "Alliance") then
		this.private.quests =
		{	
			{	--Setzlinge im Schnee
				ID = 51543,
				MapID = 896,	--Drustvar
				PosX = 0.334,
				PosY = 0.650
			},
			{	--Ein zündender Einfall
				ID = 50912,
				MapID = 896,	--Drustvar
				PosX = 0.350,
				PosY = 0.400
			},
			{	--Wildgewordene Affenbande
				ID = 53449,
				MapID = 862,	--Zuldazar
				PosX = 0.570,
				PosY = 0.585,
				isBreadcrumb = true,
				FollowUps = { 53450, 53453 }
			},
			{	--GESUCHT: Dunkelsprecher Jo'la
				ID = 51069,
				MapID = 862,	--Zuldazar
				PosX = 0.637,
				PosY = 0.102
			},
			{	--GESUCHT: Kaiserin der Säbelhauer
				ID = 53336,
				MapID = 862,	--Zuldazar
				PosX = 0.516,
				PosY = 0.455
			},
			{	--GESUCHT: Alpha der Eisenknöchel
				ID = 53337,
				MapID = 862,	--Zuldazar
				PosX = 0.516,
				PosY = 0.455
			},
			{	--Frohe Kunde (Start Tortollaner Questreihe)
				ID = 49284,
				MapID = 862,	--Zuldazar
				PosX = 0.705,
				PosY = 0.650
			},
			{	--Es liegt mir auf der Zunge
				ID = 50240,
				MapID = 1165,	--Zuldazar>Dazar'alor
				PosX = 0.535,
				PosY = 0.094
			}
		}
	else
		this.private.quests = {}
	end
	
	for _,quest in pairs(this.private.quests) do
		lib.quest.AddByID(quest.ID)
		if(quest.isBreadcrumb == true) then
			for _,FollowUp in pairs(quest.FollowUps) do
				lib.quest.AddByID(FollowUp)
			end
		end
	end
	
	return
end

function this.private.CheckPrintForBreadcrumb(Quest)
	this.private.Validate()
	
	if(Quest.isBreadcrumb ~= true) then
		return true
	end
	
	for _,FollowUp in pairs(Quest.FollowUps) do
		local Q = lib.quest.GetByID(FollowUp)
		if(Q.IsCompleted or Q.IsInLog) then
			return false
		end
	end

	return true
end

function this.private.Update()
	this.private.Validate()
	
	local out = lib.chat.output
	out.ClearBuffer()
	
	--[[
	there is a complication with "breadcrumb" quests. BC quests are quests that lead you to a NPC with more
	quests, but once you completed any of those followup quests (or have them in your log) you will no longer
	be able to accept the BC quest.
	the way this addon will handle it is as follows:
	IF a quest is a BC quest check if completed as usual
		IF the quest has not been completed, check if any of the Followup quests are in the log or completed
			IF they are not, show the quest (and comment it as breadcrumb)
			IF they are, consider the breadcrumb done
	--]]
	
	for _,quest in pairs(this.private.quests) do
		lib.quest.UpdateByID(quest.ID)
		if(quest.isBreadcrumb == true) then
			for _,FollowUp in pairs(quest.FollowUps) do
				lib.quest.UpdateByID(FollowUp)
			end
		end
		
		local Q = lib.quest.GetByID(quest.ID)
		
		if(Q.IsCompleted == true) then
			out.StoreCompleted(Q.Link)
		elseif(Q.IsInLog == true) then
			out.StoreDone(Q.Link)
		else
			local MapName = lib.map.GetNameByID(quest.MapID)
			local PrintQuest = this.private.CheckPrintForBreadcrumb(quest)
			local msg = Q.Link..lib.tomtom.createLink(quest.MapID,quest.PosX,quest.PosY,Q.Name,MapName)
				
			if(PrintQuest == true) then
				out.StoreTodo(msg)
			else
				out.StoreDone(Q.Link)
			end
		end
	end
	
	return
end

function this.CheckStatus()
	this.private.Validate()
	
	this.private.Update()
	if(lib.chat.output.GetNumLines() == 0) then
		return false
	end
	
	return true
end

function this.Script()
	this.private.Validate()
	
	this.private.Update()
	lib.chat.output.PrintModule(this.Name)
	
	return
end

mod[#mod+1] =
{
	CheckStatus	= this.CheckStatus,
	Text		= this.Name,
	Script		= this.Script
}
